API
================

pyrolite\.plot
------------------------

 .. automodule:: pyrolite.plot

 .. toctree::
   :glob:
   :maxdepth: 1

   plot/pyroplot
   plot/spider
   plot/density/density
   plot/density/density_grid
   plot/density/density_ternary
   plot/parallel
   plot/stem
   plot/biplot
   plot/templates
   plot/color

pyrolite\.geochem
------------------------

  .. automodule:: pyrolite.geochem

  .. toctree::
    :glob:
    :maxdepth: 1

    geochem/pyrochem
    geochem/ind
    geochem/transform
    geochem/norm
    geochem/parse
    geochem/magma
    geochem/alteration
    geochem/ions
    geochem/isotope


pyrolite\.comp
-----------------

  .. automodule:: pyrolite.comp

  .. toctree::
    :glob:
    :maxdepth: 1

    comp/pyrocomp
    comp/codata
    comp/aggregate
    comp/impute

pyrolite\.mineral
-------------------

  .. automodule:: pyrolite.mineral

  .. toctree::
     :maxdepth: 1

     mineral

pyrolite\.util
----------------

  .. automodule:: pyrolite.util

  .. toctree::
    :maxdepth: 2

    util/general
    util/pd
    util/plot
    util/text
    util/web
    util/time
    util/math
    util/lambdas
    util/distributions
    util/synthetic
    util/spatial
    util/resampling
    util/missing
    util/units
    util/types
    util/meta
    util/skl
    util/classification
    util/log


.. seealso:: `Extensions <../ext/extensions.html>`__
